<?php
include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

if (!isset($_GET['package_id']) || !isset($_GET['billing_cycle'])) {
    header('Location: packages.php');
    exit();
}

$user_id = $_SESSION['user_id'];
$package_id = intval($_GET['package_id']);
$billing_cycle = $_GET['billing_cycle'];

// Fetch package details
$stmt = $conn->prepare("SELECT * FROM packages WHERE id = ?");
$stmt->execute([$package_id]);
$package = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$package) {
    header('Location: packages.php');
    exit();
}

// Fetch user's current subscription
$stmt = $conn->prepare("SELECT subscriptions.*, packages.website_limit FROM subscriptions 
                        JOIN packages ON subscriptions.package_id = packages.id 
                        WHERE subscriptions.user_id = ? AND subscriptions.status = 'Active'");
$stmt->execute([$user_id]);
$current_subscription = $stmt->fetch(PDO::FETCH_ASSOC);

// Fetch the number of websites user has already added
$stmt = $conn->prepare("SELECT COUNT(*) as website_count FROM cdn_websites WHERE user_id = ?");
$stmt->execute([$user_id]);
$website_count = $stmt->fetch(PDO::FETCH_ASSOC)['website_count'];

$can_downgrade = $package['website_limit'] >= $website_count || $package['website_limit'] == -1;

if ($current_subscription && $current_subscription['package_id'] == $package_id) {
    header('Location: packages.php');
    exit();
}

if (!$can_downgrade && $package['website_limit'] != -1) {
    echo "<script>alert('You have more websites than the limit of this package. Please delete some websites before downgrading.'); window.location.href = 'packages.php';</script>";
    exit();
}

$pageTitle = "Checkout";
include('../../includes/header.php');
include('../../includes/sidebar.php');
include('../../includes/topbar.php');

// Fetch available payment gateways
$stmt = $conn->prepare("SELECT * FROM payment_gateways WHERE status = 'Active'");
$stmt->execute();
$payment_gateways = $stmt->fetchAll(PDO::FETCH_ASSOC);

?>

<div id="content-wrapper" class="d-flex flex-column">
    <!-- Main Content -->
    <div id="content">
        <div class="container-fluid">
            <h1 class="h3 mb-4 text-gray-800">Checkout</h1>
            <div class="card shadow mb-4">
                <div class="card-header py-3">
                    <h6 class="m-0 font-weight-bold text-primary">Confirm Your Package</h6>
                </div>
                <div class="card-body">
                    <div class="row">
                        <div class="col-lg-6">
                            <div class="card mb-4 shadow-sm">
                                <div class="card-body">
                                    <h5>Selected Package: <span class="text-primary"><?php echo htmlspecialchars($package['name']); ?></span></h5>
                                    <p>Price: <strong>$<?php echo htmlspecialchars($billing_cycle == 'monthly' ? $package['monthly_price'] : $package['yearly_price']); ?></strong> per <?php echo htmlspecialchars($billing_cycle); ?></p>
                                    <p>Features:</p>
                                    <ul class="list-unstyled">
                                        <?php foreach (explode("\n", $package['features']) as $feature): ?>
                                            <li><i class="fas fa-check text-success"></i> <?php echo htmlspecialchars($feature); ?></li>
                                        <?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="card mb-4 shadow-sm">
                                <div class="card-body">
                                    <form method="post" action="process_payment.php">
                                        <input type="hidden" name="package_id" value="<?php echo htmlspecialchars($package['id']); ?>">
                                        <input type="hidden" name="billing_cycle" value="<?php echo htmlspecialchars($billing_cycle); ?>">
                                        <div class="form-group">
                                            <label for="gateway_name">Select Payment Gateway</label>
                                            <select class="form-control" id="gateway_name" name="gateway_name" required>
                                                <?php foreach ($payment_gateways as $gateway): ?>
                                                    <option value="<?php echo htmlspecialchars($gateway['name']); ?>"><?php echo htmlspecialchars($gateway['name']); ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </div>
                                        <button type="submit" class="btn btn-primary btn-block">Proceed to Payment</button>
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Footer -->
    <?php include('../../includes/footer.php'); ?>
</div>

<script src="../../assets/js/jquery.min.js"></script>
<script src="../../assets/js/bootstrap.bundle.min.js"></script>
<script src="../../assets/js/sb-admin-2.min.js"></script>
</body>
</html>
