<?php
include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

$pageTitle = "Invoices";
include('../../includes/header.php');
include('../../includes/sidebar.php');
include('../../includes/topbar.php');

$user_id = $_SESSION['user_id'];

// Fetch invoices and package names
$stmt = $conn->prepare("SELECT invoices.id AS invoice_id, invoices.amount, invoices.status, invoices.created_at AS payment_date, invoices.gateway_name, packages.name AS package_name 
                        FROM invoices 
                        JOIN packages ON invoices.package_id = packages.id 
                        WHERE invoices.user_id = ?");
$stmt->execute([$user_id]);
$invoices = $stmt->fetchAll(PDO::FETCH_ASSOC);

function getStatusClass($status) {
    switch (strtolower($status)) {
        case 'paid':
            return 'text-success font-weight-bold';
        case 'pending':
            return 'text-warning font-weight-bold';
        case 'failed':
            return 'text-danger font-weight-bold';
        default:
            return 'text-secondary font-weight-bold';
    }
}
?>

<div id="content-wrapper" class="d-flex flex-column">
    <!-- Main Content -->
    <div id="content">
        <div class="container-fluid">
            <h1 class="h3 mb-4 text-gray-800">Invoices</h1>
            <div class="card shadow mb-4">
                <div class="card-header py-3">
                    <h6 class="m-0 font-weight-bold text-primary">Invoice List</h6>
                </div>
                <div class="card-body">
                    <div class="table-responsive">
                        <table class="table table-bordered" id="dataTable" width="100%" cellspacing="0">
                            <thead>
                                <tr>
                                    <th>Invoice ID</th>
                                    <th>Package Name</th>
                                    <th>Amount</th>
                                    <th>Payment Status</th>
                                    <th>Payment Date</th>
                                    <th>Payment Gateway</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($invoices as $invoice): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($invoice['invoice_id']); ?></td>
                                        <td><?php echo htmlspecialchars($invoice['package_name']); ?></td>
                                        <td>$<?php echo htmlspecialchars($invoice['amount']); ?></td>
                                        <td class="<?php echo getStatusClass($invoice['status']); ?>"><?php echo htmlspecialchars($invoice['status']); ?></td>
                                        <td><?php echo isset($invoice['payment_date']) ? date('d-M-Y', strtotime($invoice['payment_date'])) : 'N/A'; ?></td>
                                        <td><?php echo htmlspecialchars($invoice['gateway_name']); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Footer -->
    <?php include('../../includes/footer.php'); ?>
</div>

<script src="../../assets/js/jquery.min.js"></script>
<script src="../../assets/js/bootstrap.bundle.min.js"></script>
<script src="../../assets/js/sb-admin-2.min.js"></script>
</body>
</html>
