<?php
include('../../includes/db.php');
include('../../includes/functions.php');
check_login();
check_user();

$pageTitle = "View Tickets";
include('../../includes/header.php');
include('../../includes/sidebar.php');
include('../../includes/topbar.php');

$user_id = $_SESSION['user_id'];
$stmt = $conn->prepare("SELECT * FROM tickets WHERE user_id = ?");
$stmt->execute([$user_id]);
$tickets = $stmt->fetchAll(PDO::FETCH_ASSOC);

function getStatusClass($status) {
    switch (strtolower($status)) {
        case 'open':
            return 'text-success font-weight-bold';
        case 'closed':
            return 'text-danger font-weight-bold';
        case 'pending':
            return 'text-warning font-weight-bold';
        default:
            return 'text-secondary font-weight-bold';
    }
}

function formatDate($datetime) {
    $date = new DateTime($datetime);
    $now = new DateTime();
    $interval = $now->diff($date);
    
    if ($interval->y >= 1 || $interval->m >= 1) {
        return $date->format('d-M-Y');
    }
    
    return $date->format('d-M-Y H:i:s');
}
?>

<div id="content-wrapper" class="d-flex flex-column">
    <!-- Main Content -->
    <div id="content">
        <div class="container-fluid">
            <h1 class="h3 mb-4 text-gray-800">My Support Tickets</h1>
            <div class="card shadow mb-4">
                <div class="card-header py-3">
                    <h6 class="m-0 font-weight-bold text-primary">Tickets</h6>
                </div>
                <div class="card-body">
                    <div class="table-responsive">
                        <table class="table table-bordered" id="dataTable" width="100%" cellspacing="0">
                            <thead>
                                <tr>
                                    <th>Ticket ID</th>
                                    <th>Subject</th>
                                    <th>Status</th>
                                    <th>Created At</th>
                                    <th>Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($tickets as $ticket): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($ticket['ticket_id']); ?></td>
                                        <td><?php echo htmlspecialchars($ticket['subject']); ?></td>
                                        <td class="<?php echo getStatusClass($ticket['status']); ?>"><?php echo htmlspecialchars($ticket['status']); ?></td>
                                        <td><?php echo formatDate($ticket['created_at']); ?></td>
                                        <td>
                                            <a href="view_ticket.php?id=<?php echo urlencode($ticket['ticket_id']); ?>" class="btn btn-info btn-sm">View</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- Footer -->
    <?php include('../../includes/footer.php'); ?>
</div>

<script src="../../assets/js/jquery.min.js"></script>
<script src="../../assets/js/bootstrap.bundle.min.js"></script>
<script src="../../assets/js/sb-admin-2.min.js"></script>
</body>
</html>
